"""
Sistema Estadístico Integral de Venezuela - (SEIVEN)

Copyleft (@) 2015 CENDITEL nodo Mérida - https://mpv.cenditel.gob.ve/seiven
"""
## @namespace productivo.services
#
# Contiene los métodos para consumir servicios REST
# @author Ing. Roldan Vargas (rvargas at cenditel.gob.ve)
# @author <a href='http://www.cenditel.gob.ve'>Centro Nacional de Desarrollo e Investigación en Tecnologías Libres
# (CENDITEL) nodo Mérida - Venezuela</a>
# @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
from __future__ import unicode_literals

import json

from .models import AccessToken
import requests

consult_api = False
params = {}

def api_anho_registro():
    """!
    Función que permite obtener los años de registro del SIDEPRO

    @author Ing. Roldan Vargas (rvargas at cenditel.gob.ve)
    @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
    @date 15-09-2017
    @return Devuelve un JSON con los datos consultados
    """
    global consult_api
    access_credentials = AccessToken.objects.filter(activo=True)

    if access_credentials:
        token_type = access_credentials[0].token_type
        token = access_credentials[0].access_token
        url = access_credentials[0].url_access + "api/anhos"

        consult_api = requests.get(url=url, headers={'Authorization': '%s %s' % (token_type, token)})
    return json.loads(consult_api.text)


def api_estados():
    """!
    Función que permite obtener los Estados registrados en SIDEPRO

    @author Ing. Roldan Vargas (rvargas at cenditel.gob.ve)
    @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
    @date 15-09-2017
    @return Devuelve un JSON con los datos consultados
    """
    global consult_api
    access_credentials = AccessToken.objects.filter(activo=True)

    if access_credentials:
        token_type = access_credentials[0].token_type
        token = access_credentials[0].access_token
        url = access_credentials[0].url_access + "api/estados"

        consult_api = requests.get(url=url, headers={'Authorization': '%s %s' % (token_type, token)})

    return json.loads(consult_api.text)


def api_unidad_economica(rif=None, nombre=None, estado=None, anho=None, id_list=None):
    """!
    Función que permite obtener las Unidades Económicas registradas en SIDEPRO

    @author Ing. Roldan Vargas (rvargas at cenditel.gob.ve)
    @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
    @date 15-09-2017
    @param rif <b>{string}</b> Número de RIF de la Unidad Económica
    @param nombre <b>{string}</b> Nombre de la Unidad Económica
    @param estado <b>{string}</b> Estado de la Unidad Económica
    @param anho <b>{string}</b> Año de registro de la Unidad Económica
    @param id_list <b>{array}</b> Listado de ID de Unidades Económicas
    @return Devuelve un JSON con los datos consultados
    """
    global consult_api
    access_credentials = AccessToken.objects.filter(activo=True)

    if access_credentials:
        token_type = access_credentials[0].token_type
        token = access_credentials[0].access_token
        url = access_credentials[0].url_access + "api/unidad-economica"

        ## Actualiza los datos de consulta por rif si se ha especificado
        params.update({'rif': rif} if rif else {})
        ## Actualiza los datos de consulta por nombre de la unidad económica si se ha especificado
        params.update({'nombre': nombre} if nombre else {})
        ## Actualiza los datos de consulta por estado si se ha especificado
        params.update({'estado': estado} if estado else {})
        ## Actualiza los datos de consulta por año de registro si se ha especificado
        params.update({'anho': anho} if anho else {})
        ## Actualiza los datos de consulta por lista de ids si se han especificado
        #params.update({'id_list': id_list} if id_list else {})

        consult_api = requests.get(url=url, headers={'Authorization': '%s %s' % (token_type, token)}, params=params)

    return  json.loads(consult_api.text)


def api_filter_ue(filtros=None, id_list=None):
    """!
    Función que permite obtener las Unidades Económicas de acuerdo al filtro indicado

    @author Ing. Roldan Vargas (rvargas at cenditel.gob.ve)
    @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
    @date 20-12-2017
    @param filtros <b>{array}</b> Listado de opciones a consultar
    @return Devuelve un JSON con los datos consultados
    """
    global consult_api
    access_credentials = AccessToken.objects.filter(activo=True)

    if access_credentials:
        token_type = access_credentials[0].token_type
        token = access_credentials[0].access_token
        url = access_credentials[0].url_access + "api/unidad-economica"

        params.update({'id_list': id_list} if id_list else {})

        consult_api = requests.get(url=url, headers={'Authorization': '%s %s' % (token_type, token)}, params=params)

        print(consult_api)

    return json.loads(consult_api.text)

def api_filter_su(filtros=None):
    """!
    Función que permite obtener las Sub Unidades Económicas de acuerdo al filtro indicado

    @author Ing. Roldan Vargas (rvargas at cenditel.gob.ve)
    @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
    @date 20-12-2017
    @param filtros <b>{array}</b> Listado de opciones a consultar
    @return Devuelve un JSON con los datos consultados
    """
    global consult_api
    access_credentials = AccessToken.objects.filter(activo=True)

    if access_credentials:
        token_type = access_credentials[0].token_type
        token = access_credentials[0].access_token
        url = access_credentials[0].url_access + ""

    return json.loads(consult_api.text)

def api_filter_pp(filtros=None):
    """!
    Función que permite obtener el proceso productivo de las Unidades Económicas de acuerdo al filtro indicado

    @author Ing. Roldan Vargas (rvargas at cenditel.gob.ve)
    @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
    @date 20-12-2017
    @param filtros <b>{array}</b> Listado de opciones a consultar
    @return Devuelve un JSON con los datos consultados
    """
    global consult_api
    access_credentials = AccessToken.objects.filter(activo=True)

    if access_credentials:
        token_type = access_credentials[0].token_type
        token = access_credentials[0].access_token
        url = access_credentials[0].url_access + ""

    return json.loads(consult_api.text)


def api_filter_ae(filtros=None):
    """!
    Función que permite obtener las actividades económicas de las Unidades Económicas de acuerdo al filtro indicado

    @author Ing. Roldan Vargas (rvargas at cenditel.gob.ve)
    @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
    @date 20-12-2017
    @param filtros <b>{array}</b> Listado de opciones a consultar
    @return Devuelve un JSON con los datos consultados
    """
    global consult_api
    access_credentials = AccessToken.objects.filter(activo=True)

    if access_credentials:
        token_type = access_credentials[0].token_type
        token = access_credentials[0].access_token
        url = access_credentials[0].url_access + ""

    return json.loads(consult_api.text)
