"""
Sistema Estadístico Integral de Venezuela - (SEIVEN)

Copyleft (@) 2015 CENDITEL nodo Mérida - https://mpv.cenditel.gob.ve/seiven
"""
## @namespace productivo.models
#
# Contiene las clases, atributos, métodos y/o funciones a implementar para los modelos del área productiva
# @author Ing. Roldan Vargas (rvargas at cenditel.gob.ve)
# @author <a href='http://www.cenditel.gob.ve'>Centro Nacional de Desarrollo e Investigación en Tecnologías Libres
# (CENDITEL) nodo Mérida - Venezuela</a>
# @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
from __future__ import unicode_literals

import logging
import json

from django.http import HttpResponse
from django.utils.translation import ugettext_lazy as _
from django.contrib.auth.decorators import login_required

from base.messages import MSG_NOT_AJAX
from api_client.services import api_unidad_economica

"""!
Contiene el objeto que registra la vitacora de eventos del módulo productivo.
(configuración en el settings de la aplicación)
"""
logger = logging.getLogger("productivo")

__licence__ = "GNU Public License v2"
__revision__ = ""
__docstring__ = "DoxyGen"


@login_required
def get_unidad_economica(request):
    """!
    Función que permite obtener los datos de las Unidades Económicas consultadas mediante el API de SIDEPRO

    @author Ing. Roldan Vargas (rvargas at cenditel.gob.ve)
    @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
    @date 15-09-2017
    @param request <b>{object}</b> Objeto que obtiene la petición
    @return Devuelve el response con la página del sub-menu de consulta del área productiva
    """
    try:
        if not request.is_ajax():
            return HttpResponse(json.dumps({'result': False, 'message': str(MSG_NOT_AJAX)}))

        rif = request.POST.get('rif', None)
        nombre = request.POST.get('nombre', None)
        estado = request.POST.get('estado', None)
        anho = request.POST.get('anho', None)
        id_list = request.POST.get('id_list', None)
        message = _('No existen datos')

        data = api_unidad_economica(rif, nombre, estado, anho, id_list)

        if data['results']:
            return HttpResponse(json.dumps({
                'result': True, 'unidades_economicas': data['results'], 'message': ''
            }))

    except Exception as e:
        message = e

    return HttpResponse(json.dumps({'result': False, 'message': str(message)}))

@login_required
def get_result_unidad_economica(request):
    try:
        if not request.is_ajax():
            return HttpResponse(json.dumps({'result': False, 'message': str(MSG_NOT_AJAX)}))

        items_ue = request.POST.getlist('items_ue[]')
        items_su = request.POST.getlist('items_su[]')
        items_pp = request.POST.getlist('items_pp[]')
        items_ae = request.POST.getlist('items_ae[]')
        id_list = request.POST.getlist('id_list[]')
        print(id_list)
        data = api_unidad_economica(id_list)
        message = _('No existen datos')


        #data = api_unidad_economica(rif, nombre, estado, anho, id_list)

        #if data['results']:
        #    return HttpResponse(json.dumps({
        #        'result': True, 'unidades_economicas': data['results'], 'message': ''
        #    }))

    except Exception as e:
        message = e

    return HttpResponse(json.dumps({'result': False, 'message': str(message)}))
